// This program will log the Date, Time and pH reading to the serial monitor and any other serial monitoring program
// You can modify this program to log DO, EC, or Temp on a PC, MAC or Linux computer
// Connect the Transmitter to the USB B port to upload code and log data
// Consult the manual or other examples for the DO, EC and Temp data request commands
// We use the Coolterm program to log the file to a txt file http://freeware.the-meiers.org/


// the 4 commands below are necessary for the Boekel OSB library to work
#include <Wire.h>
#include <Boekel_OpenSourceBio.h>
using namespace Boekel;
OpenSourceBio osb; // create osb object.

// The osb object returns the month, day, and year as integers.
// To use them in the displayText function we need to change them to chars.
// The variables below will be used to store the day and time info

char mm[3]; // we add an extra index to account for the null character.
char dd[3];
char yy[5];
char hh[3];
char min[3];
char ss[3];

char date[22]; // we will put the string dd/mm/yyyy hh:mm:ss in the date[] array



//The setup function will only run once
void setup()
{
delay(1500);  // The main board takes a second to warm up.  This delay ensures it is ready to communicate
Serial.begin(9600); // the data is also outputted to the serial terminal, enter a keystroke to start
}

void loop()
{

    double reading; // this is where we'll put the probe's read value
    char readingBuffer[12]; // To display the "reading" we need to convert it to a string/array of characters,
                            // we'll use "readingBuffer" as the array.
    
    osb.updateReadings(); // This command updates the transmitter readings 

    // Obtains Date and Time info from the Boekel Board
    // Convert integers to string 
    // itoa char *  itoa ( int value, char * str, int base ); Converts an integer value to a null-terminated string
    itoa(osb.getMonth(),mm,10); 
    itoa(osb.getDay(),dd,10);
    itoa(osb.getYear(),yy,10);
    itoa(osb.getHours(),hh,10);
    itoa(osb.getMinutes(),min,10);
    itoa(osb.getSeconds(),ss,10);

    // Build the date and time string "dd/mm/yyyy hh:mm:ss by concatenating/attaching month, day, year, hours, minutes, seconds 
    strcat(date,mm);
    strcat(date,"/");
    strcat(date,dd);
    strcat(date,"/");
    strcat(date,yy);
    strcat(date," ");
    strcat(date,hh);
    strcat(date,":");
    strcat(date,min);
    strcat(date,":");
    strcat(date,ss);    
    strcat(date," "); 
    
    Serial.print(date); // Print the Date Time String to the serial    
    reading = osb.getPH(); // Read value from sensor, Change this code line if you want to read DO, EC or temp.
    dtostrf(reading,2,3,readingBuffer); // convert double to string so it can be sent to serial
    Serial.println(readingBuffer); // print sensor value to serial
    delay(5000); // Delays reading every 5 seconds.  Do not go less than 3 seconds because of serial communication  
  

}

